package main

import (
	"bot/api"
	"os"

	tgbotapi "github.com/go-telegram-bot-api/telegram-bot-api/v5"
	"gopkg.in/yaml.v2"
)

type Config struct {
	Account struct {
		Token string `yaml:"token"`
		Owner int64  `yaml:"owner"`
	} `yaml:"account"`
}

var BotConfig Config

func main() {
	yamlFile, err := os.ReadFile("bot.yaml")
	if err != nil {
		panic("read yaml fail: " + err.Error())
	}
	err = yaml.Unmarshal(yamlFile, &BotConfig)
	if err != nil {
		panic("unmarshal yaml fail: " + err.Error())
	}
	api.InitBot(BotConfig.Account.Token, handleUpdate)
}

func deliverIncomingMsg(msg api.SimpleMsg) {
	api.ForwardMsg(BotConfig.Account.Owner, msg.ChatId, msg.MessageID)
}

func deliverOutgoingMsg(msg api.SimpleMsg) {
	if msg.SourceForwardId == 0 {
		api.SendMsg(msg.ChatId, "需要回复转发的消息")
	} else {
		if msg.Text != "" {
			api.SendMsg(msg.SourceForwardId, msg.Text)
		} else if msg.PhotoID != "" {
			api.SendExistingPhoto(msg.SourceForwardId, msg.PhotoID)
		} else if msg.VideoID != "" {
			api.SendExistingVideo(msg.SourceForwardId, msg.VideoID)
		}
	}
}

func handleUpdate(update tgbotapi.Update) {
	msg := api.FormatMsg(update)
	if msg.Type != "private" {
		return
	}
	if msg.Text != "" {
		if msg.Text[0] == '/' {
			return
		}
	}

	if msg.FromID != BotConfig.Account.Owner {
		deliverIncomingMsg(msg)
	} else {
		deliverOutgoingMsg(msg)
	}
}
